==> cloud-4.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Ec2/ElasticIpDisassociateForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\aws_cloud\Entity\Ec2\NetworkInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Disassociate Elastic IP address form.
 */
class ElasticIpDisassociateForm extends AwsDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    /** @var \Drupal\aws_cloud\Entity\Ec2\ElasticIp $entity */
    $entity = $this->entity;

    if ($this->ec2Service->isInstanceCloudOrchestrator($entity->getInstanceId()) === TRUE) {
      $this->messenger()->addWarning($this->t('Attempting to disassociate @ip_address from Cloud Orchestrator. Cloud Orchestrator will not be accessible if the IP address is disassociated.', [
        '@ip_address' => $entity->getPublicIp(),
      ]));
    }

    return $this->t('Are you sure you want to disassociate this Elastic IP address (@ip_address)', [
      '@ip_address' => $entity->getPublicIp(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    $entity = $this->entity;
    $instance_id = $entity->getInstanceId();
    $network_interface_id = $entity->getNetworkInterfaceId();

    // Get module name.
    $module_name = $this->getModuleName($entity);

    $msg = '<h2>Elastic IP Information:</h2>';
    $msg .= '<ul>';

    if (empty($instance_id) && empty($network_interface_id)) {
      $msg .= $this->t('<li>No information available for Instance ID and Network ID.</li>');
    }

    if (!empty($instance_id)) {
      $instance = $this->getInstanceById($instance_id, $module_name, $entity->getCloudContext());
      $instance_link = $this->entityLinkRenderer->renderViewElement(
        $instance_id,
        "{$module_name}_instance",
        'instance_id',
        [],
        $instance->getName() !== $instance->getInstanceId() ? $this->t('@instance_name (@instance_id)', [
          '@instance_name' => $instance->getName(),
          '@instance_id' => $instance_id,
        ]) : $instance_id
      );

      $msg .= $this->t('<li>Instance ID: @instance_id</li>',
        [
          '@instance_id' => Markup::create($instance_link['#markup']),
        ]
      );
    }

    if (!empty($network_interface_id)) {
      $network_interface = $this->getNetworkInterfaceById($network_interface_id, $module_name, $entity->getCloudContext());

      $network_interface_link = $this->entityLinkRenderer->renderViewElement(
        $network_interface_id,
        "{$module_name}_network_interface",
        'network_interface_id',
        [],
        $network_interface->getName() !== $network_interface->getNetworkInterfaceId() ? $this->t('@network_interface_name (@network_interface_id)', [
          '@network_interface_name' => $network_interface->getName(),
          '@network_interface_id' => $network_interface_id,
        ]) : $network_interface_id
      );

      $msg .= $this->t('<li>Network ID: @network_id</li>',
        [
          '@network_id' => Markup::create($network_interface_link['#markup']),
        ]
      );
    }

    $msg .= $this->t('</ul>');

    return $msg;
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Disassociate Address');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    if (!$this->updateEntityBuildForm($this->entity)) {
      return $this->redirectUrl;
    }
    $form = parent::buildForm($form, $form_state);
    if ($this->entity->getAssociationId() === NULL) {
      $form['error'] = [
        '#markup' => '<div>' . $this->t('Elastic IP is already disassociated') . '</div>',
      ];
      unset($form['description']);
      unset($form['actions']['submit']);
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->ec2Service->setCloudContext($this->entity->getCloudContext());
    $entity = $this->entity;

    // Get module name.
    $module_name = $this->getModuleName($entity);

    $instance_id = $entity->getInstanceId();
    $network_interface_id = $entity->getNetworkInterfaceId();

    $result = $this->ec2Service->disassociateAddress([
      'AssociationId' => $this->entity->getAssociationId(),
    ]);
    if ($result !== NULL) {
      if (!empty($instance_id)) {
        $instance = $this->getInstanceById($instance_id, $module_name, $entity->getCloudContext());
        $instance_link = $this->entityLinkRenderer->renderViewElement(
        $instance_id,
        "{$module_name}_instance",
        'instance_id',
        [],
        !empty($instance->getName()) !== $instance->getInstanceId()
          ? $this->t('@instance_name (@instance_id)', [
            '@instance_name' => $instance->getName(),
            '@instance_id' => $instance_id,
          ])
          : $instance_id
        );
      }
      if (!empty($network_interface_id)) {
        $network_interface = $this->getNetworkInterfaceById($network_interface_id, $module_name, $entity->getCloudContext());
        $network_interface_link = $this->entityLinkRenderer->renderViewElement(
        $network_interface_id,
        "{$module_name}_network_interface",
        'network_interface_id',
        [],
        $network_interface->getName() !== $network_interface->getNetworkInterfaceId()
          ? $this->t('@network_interface_name (@network_interface_id)', [
            '@network_interface_name' => $network_interface->getName(),
            '@network_interface_id' => $network_interface_id,
          ])
          : $network_interface_id
        );
      }

      $this->messenger->addStatus($this->t('Elastic IP disassociated from: <ul><li>
        Instance: @instance_id </li> <li>Network: @network_id</li></ul>', [
          '@instance_id' => Markup::create($instance_link['#markup']),
          '@network_id' => Markup::create($network_interface_link['#markup']),
        ]));
      $this->ec2Service->updateElasticIps();
      $this->ec2Service->updateInstances();
      $this->ec2Service->updateNetworkInterfaces();

      $this->clearCacheValues($entity->getCacheTags());
      $this->dispatchSubmitEvent($entity);
    }
    else {
      $this->messenger->addError($this->t('Unable to disassociate Elastic IP.'));
    }
    $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
  }

  /**
   * Helper method to load instance by ID.
   *
   * @param string $instance_id
   *   Instance ID to load.
   * @param string $module_name
   *   Module name.
   * @param string $cloud_context
   *   Cloud context.
   *
   * @return \Drupal\aws_cloud\Entity\Ec2\Instance
   *   The Instance entity.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function getInstanceById($instance_id, $module_name, $cloud_context): InstanceInterface {
    $instances = $this->entityTypeManager
      ->getStorage("{$module_name}_instance")
      ->loadByProperties([
        'instance_id' => $instance_id,
        'cloud_context' => $cloud_context,
      ]);
    return array_shift($instances);
  }

  /**
   * Helper method to load Network Interface by ID.
   *
   * @param string $network_interface_id
   *   Network Interface ID to load.
   * @param string $module_name
   *   Module name.
   * @param string $cloud_context
   *   Cloud context.
   *
   * @return \Drupal\aws_cloud\Entity\Ec2\NetworkInterface
   *   The NetworkInterface entity.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function getNetworkInterfaceById($network_interface_id, $module_name, $cloud_context): NetworkInterface {
    $network_interface = $this->entityTypeManager
      ->getStorage("{$module_name}_network_interface")
      ->loadByProperties([
        'network_interface_id' => $network_interface_id,
        'cloud_context' => $cloud_context,
      ]);
    return array_shift($network_interface);
  }

}

==> cloud-5.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Ec2/ElasticIpDisassociateForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\aws_cloud\Entity\Ec2\NetworkInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Disassociate Elastic IP address form.
 */
class ElasticIpDisassociateForm extends AwsDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    /** @var \Drupal\aws_cloud\Entity\Ec2\ElasticIp $entity */
    $entity = $this->entity;

    if ($this->ec2Service->isInstanceCloudOrchestrator($entity->getInstanceId()) === TRUE) {
      $this->messenger()->addWarning($this->t('Attempting to disassociate @ip_address from Cloud Orchestrator. Cloud Orchestrator will not be accessible if the IP address is disassociated.', [
        '@ip_address' => $entity->getPublicIp(),
      ]));
    }

    return $this->t('Are you sure you want to disassociate this Elastic IP address (@ip_address)', [
      '@ip_address' => $entity->getPublicIp(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    $entity = $this->entity;
    $instance_id = $entity->getInstanceId();
    $network_interface_id = $entity->getNetworkInterfaceId();

    // Get module name.
    $module_name = $this->getModuleName($entity);

    $msg = '<h2>Elastic IP Information:</h2>';
    $msg .= '<ul>';

    if (empty($instance_id) && empty($network_interface_id)) {
      $msg .= $this->t('<li>No information available for Instance ID and Network ID.</li>');
    }

    if (!empty($instance_id)) {
      $instance = $this->getInstanceById($instance_id, $module_name, $entity->getCloudContext());
      $instance_link = $this->entityLinkRenderer->renderViewElement(
        $instance_id,
        "{$module_name}_instance",
        'instance_id',
        [],
        $instance->getName() !== $instance->getInstanceId() ? $this->t('@instance_name (@instance_id)', [
          '@instance_name' => $instance->getName(),
          '@instance_id' => $instance_id,
        ]) : $instance_id
      );

      $msg .= $this->t('<li>Instance ID: @instance_id</li>',
        [
          '@instance_id' => Markup::create($instance_link['#markup']),
        ]
      );
    }

    if (!empty($network_interface_id)) {
      $network_interface = $this->getNetworkInterfaceById($network_interface_id, $module_name, $entity->getCloudContext());

      $network_interface_link = $this->entityLinkRenderer->renderViewElement(
        $network_interface_id,
        "{$module_name}_network_interface",
        'network_interface_id',
        [],
        $network_interface->getName() !== $network_interface->getNetworkInterfaceId() ? $this->t('@network_interface_name (@network_interface_id)', [
          '@network_interface_name' => $network_interface->getName(),
          '@network_interface_id' => $network_interface_id,
        ]) : $network_interface_id
      );

      $msg .= $this->t('<li>Network ID: @network_id</li>',
        [
          '@network_id' => Markup::create($network_interface_link['#markup']),
        ]
      );
    }

    $msg .= $this->t('</ul>');

    return $msg;
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Disassociate Address');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if (!$this->updateEntityBuildForm($this->entity)) {
      return $this->redirectUrl;
    }
    $form = parent::buildForm($form, $form_state);
    if ($this->entity->getAssociationId() === NULL) {
      $form['error'] = [
        '#markup' => '<div>' . $this->t('Elastic IP is already disassociated') . '</div>',
      ];
      unset($form['description']);
      unset($form['actions']['submit']);
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->ec2Service->setCloudContext($this->entity->getCloudContext());
    $entity = $this->entity;

    $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);

    $result = $this->ec2Service->disassociateAddress([
      'AssociationId' => $this->entity->getAssociationId(),
    ]);

    if ($result === NULL) {
      $this->messenger->addError($this->t('Unable to disassociate Elastic IP.'));
      return;
    }

    // Get module name.
    $module_name = $this->getModuleName($entity);

    $instance_id = $entity->getInstanceId();
    $network_interface_id = $entity->getNetworkInterfaceId();

    if (!empty($instance_id)) {
      $instance = $this->getInstanceById($instance_id, $module_name, $entity->getCloudContext());
      $instance_link = $this->entityLinkRenderer->renderViewElement(
        $instance_id,
        "{$module_name}_instance",
        'instance_id',
        [],
        !empty($instance->getName()) !== $instance->getInstanceId()
          ? $this->t('@instance_name (@instance_id)', [
            '@instance_name' => $instance->getName(),
            '@instance_id' => $instance_id,
          ])
          : $instance_id
      );
    }
    if (!empty($network_interface_id)) {
      $network_interface = $this->getNetworkInterfaceById($network_interface_id, $module_name, $entity->getCloudContext());
      $network_interface_link = $this->entityLinkRenderer->renderViewElement(
        $network_interface_id,
        "{$module_name}_network_interface",
        'network_interface_id',
        [],
        $network_interface->getName() !== $network_interface->getNetworkInterfaceId()
          ? $this->t('@network_interface_name (@network_interface_id)', [
            '@network_interface_name' => $network_interface->getName(),
            '@network_interface_id' => $network_interface_id,
          ])
          : $network_interface_id
      );
    }

    if (!empty($result['SendToWorker'])) {
      $this->messenger->addStatus($this->t('Elastic IP disassociated from remotely: <ul><li>
        Instance: @instance_id </li> <li>Network: @network_id</li></ul>', [
          '@instance_id' => Markup::create($instance_link['#markup']),
          '@network_id' => Markup::create($network_interface_link['#markup']),
        ]));
      $this->messenger->addStatus($message);
      return;
    }

    $this->messenger->addStatus($this->t('Elastic IP disassociated from: <ul><li>
      Instance: @instance_id </li> <li>Network: @network_id</li></ul>', [
        '@instance_id' => Markup::create($instance_link['#markup']),
        '@network_id' => Markup::create($network_interface_link['#markup']),
      ]));
    $this->ec2Service->updateElasticIps();
    $this->ec2Service->updateInstances();
    $this->ec2Service->updateNetworkInterfaces();

    $this->clearCacheValues($entity->getCacheTags());
    $this->dispatchSubmitEvent($entity);
  }

  /**
   * Helper method to load instance by ID.
   *
   * @param string $instance_id
   *   Instance ID to load.
   * @param string $module_name
   *   Module name.
   * @param string $cloud_context
   *   Cloud context.
   *
   * @return \Drupal\aws_cloud\Entity\Ec2\Instance
   *   The Instance entity.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function getInstanceById($instance_id, $module_name, $cloud_context): InstanceInterface {
    $instances = $this->entityTypeManager
      ->getStorage("{$module_name}_instance")
      ->loadByProperties([
        'instance_id' => $instance_id,
        'cloud_context' => $cloud_context,
      ]);
    return array_shift($instances);
  }

  /**
   * Helper method to load network interface by ID.
   *
   * @param string $network_interface_id
   *   Network interface ID to load.
   * @param string $module_name
   *   Module name.
   * @param string $cloud_context
   *   Cloud context.
   *
   * @return \Drupal\aws_cloud\Entity\Ec2\NetworkInterface
   *   The NetworkInterface entity.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function getNetworkInterfaceById($network_interface_id, $module_name, $cloud_context): NetworkInterface {
    $network_interface = $this->entityTypeManager
      ->getStorage("{$module_name}_network_interface")
      ->loadByProperties([
        'network_interface_id' => $network_interface_id,
        'cloud_context' => $cloud_context,
      ]);
    return array_shift($network_interface);
  }

}
